from ims_mcp import tool_prompts


def test_prompt_constants_non_empty():
    names = [
        "PROMPT_GET_CONTEXT_INSTRUCTIONS",
        "PROMPT_QUERY_INSTRUCTIONS",
        "PROMPT_SUBMIT_FEEDBACK",
        "PROMPT_QUERY_PROJECT_CONTEXT",
        "PROMPT_STORE_PROJECT_CONTEXT",
        "PROMPT_DISCOVER_PROJECTS",
    ]
    for name in names:
        value = getattr(tool_prompts, name)
        assert isinstance(value, str)
        assert value.strip()
